/*
 * Copyright 2015 UnboundID Corp.
 * All Rights Reserved.
 */
/*
 * Copyright (C) 2015 UnboundID Corp.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License (GPLv2 only)
 * or the terms of the GNU Lesser General Public License (LGPLv2.1 only)
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses>.
 */
package com.unboundid.ldap.sdk.unboundidds.tasks;



import java.text.MessageFormat;
import java.util.ResourceBundle;
import java.util.concurrent.ConcurrentHashMap;



/**
 * This enum defines a set of message keys for messages in the
 * com.unboundid.ldap.sdk.unboundidds.tasks package, which correspond to messages in the
 * unboundid-ldapsdk-task.properties properties file.
 * <BR><BR>
 * This source file was generated from the properties file.
 * Do not edit it directly.
 */
enum TaskMessages
{
  /**
   * Entry ''{0}'' cannot be parsed as an add schema file task because it does not have any values for the ds-task-schema-file-name attribute.
   */
  ERR_ADD_SCHEMA_FILE_TASK_NO_FILES("Entry ''{0}'' cannot be parsed as an add schema file task because it does not have any values for the ds-task-schema-file-name attribute."),



  /**
   * The provided entry cannot be parsed as an alert task definition because it does not contain either an alert type and alert message or set of alert types to add or remove from the set of degraded or unavailable alert types.
   */
  ERR_ALERT_ENTRY_NO_ELEMENTS("The provided entry cannot be parsed as an alert task definition because it does not contain either an alert type and alert message or set of alert types to add or remove from the set of degraded or unavailable alert types."),



  /**
   * The provided property set cannot be used to construct an alert task because it does not contain either an alert type and alert message or set of alert types to add or remove from the set of degraded or unavailable alert types.
   */
  ERR_ALERT_PROPERTIES_NO_ELEMENTS("The provided property set cannot be used to construct an alert task because it does not contain either an alert type and alert message or set of alert types to add or remove from the set of degraded or unavailable alert types."),



  /**
   * If either an alert type or alert message is present, then the other must also be present.
   */
  ERR_ALERT_TYPE_AND_MESSAGE_INTERDEPENDENT("If either an alert type or alert message is present, then the other must also be present."),



  /**
   * You cannot specify both include and exclude auditors when creating an audit data security task.
   */
  ERR_AUDIT_DATA_SECURITY_BOTH_INCLUDE_AND_EXCLUDE_AUDITORS("You cannot specify both include and exclude auditors when creating an audit data security task."),



  /**
   * Entry ''{0}'' cannot be parsed as a backup task because it does not specify the path to the backup directory in which to write the backup files.
   */
  ERR_BACKUP_NO_BACKUP_DIRECTORY("Entry ''{0}'' cannot be parsed as a backup task because it does not specify the path to the backup directory in which to write the backup files."),



  /**
   * Entry ''{0}'' cannot be parsed as a disconnect client task because the connection ID value ''{1}'' could not be parsed as an integer.
   */
  ERR_DISCONNECT_TASK_CONN_ID_NOT_LONG("Entry ''{0}'' cannot be parsed as a disconnect client task because the connection ID value ''{1}'' could not be parsed as an integer."),



  /**
   * Entry ''{0}'' cannot be parsed as a disconnect client task because it does not specify the connection ID for the client to disconnect.
   */
  ERR_DISCONNECT_TASK_NO_CONN_ID("Entry ''{0}'' cannot be parsed as a disconnect client task because it does not specify the connection ID for the client to disconnect."),



  /**
   * Entry {0} cannot be parsed as a dump DB details task entry because it is missing attribute {1} to specify the backend ID for the backend to examine.
   */
  ERR_DUMP_DB_ENTRY_MISSING_BACKEND_ID("Entry {0} cannot be parsed as a dump DB details task entry because it is missing attribute {1} to specify the backend ID for the backend to examine."),



  /**
   * Entry ''{0}'' cannot be parsed as an export task because value ''{1}'' of attribute ds-task-export-wrap-column cannot be parsed as an integer.
   */
  ERR_EXPORT_TASK_CANNOT_PARSE_WRAP_COLUMN("Entry ''{0}'' cannot be parsed as an export task because value ''{1}'' of attribute ds-task-export-wrap-column cannot be parsed as an integer."),



  /**
   * Entry ''{0}'' cannot be parsed as an export task because it does not specify the backend ID of the backend to export.
   */
  ERR_EXPORT_TASK_NO_BACKEND_ID("Entry ''{0}'' cannot be parsed as an export task because it does not specify the backend ID of the backend to export."),



  /**
   * Entry ''{0}'' cannot be parsed as an export task because it does not specify the path to the LDIF file to be written.
   */
  ERR_EXPORT_TASK_NO_LDIF_FILE("Entry ''{0}'' cannot be parsed as an export task because it does not specify the path to the LDIF file to be written."),



  /**
   * No fully-qualified Groovy class name was provided in task entry {0}.
   */
  ERR_GROOVY_SCRIPTED_TASK_NO_CLASS("No fully-qualified Groovy class name was provided in task entry {0}."),



  /**
   * Neither a backend ID nor set of include branches was specified.
   */
  ERR_IMPORT_TASK_NO_BACKEND_ID_OR_INCLUDE_BRANCHES("Neither a backend ID nor set of include branches was specified."),



  /**
   * Entry ''{0}'' cannot be parsed as an import task because it does not specify the path to the LDIF file(s) containing the data to import.
   */
  ERR_IMPORT_TASK_NO_LDIF("Entry ''{0}'' cannot be parsed as an import task because it does not specify the path to the LDIF file(s) containing the data to import."),



  /**
   * Entry ''{0}'' cannot be parsed as a rebuild task because value ''{1}'' for attribute ds-task-rebuild-max-threads cannot be parsed as an integer.
   */
  ERR_REBUILD_TASK_INVALID_MAX_THREADS("Entry ''{0}'' cannot be parsed as a rebuild task because value ''{1}'' for attribute ds-task-rebuild-max-threads cannot be parsed as an integer."),



  /**
   * Entry ''{0}'' cannot be parsed as a rebuild task because it does not specify the base DN for which to rebuild the indexes.
   */
  ERR_REBUILD_TASK_NO_BASE_DN("Entry ''{0}'' cannot be parsed as a rebuild task because it does not specify the base DN for which to rebuild the indexes."),



  /**
   * Entry ''{0}'' cannot be parsed as a rebuild task because it does not specify any indexes to rebuild.
   */
  ERR_REBUILD_TASK_NO_INDEXES("Entry ''{0}'' cannot be parsed as a rebuild task because it does not specify any indexes to rebuild."),



  /**
   * Entry ''{0}'' cannot be parsed as a re-encode entries task because it does not have a value for the required ''{1}'' attribute.
   */
  ERR_REENCODE_TASK_MISSING_REQUIRED_ATTR("Entry ''{0}'' cannot be parsed as a re-encode entries task because it does not have a value for the required ''{1}'' attribute."),



  /**
   * Property ''{0}'' is required for a re-encode entries task but was not provided.
   */
  ERR_REENCODE_TASK_MISSING_REQUIRED_PROPERTY("Property ''{0}'' is required for a re-encode entries task but was not provided."),



  /**
   * Unable to create a reload global index task from the provided entry because the required ''{0}'' attribute was not included.
   */
  ERR_RELOAD_GLOBAL_INDEX_MISSING_REQUIRED_ATTR("Unable to create a reload global index task from the provided entry because the required ''{0}'' attribute was not included."),



  /**
   * Unable to create a reload global index task from the provided set of properties because the required ''{0}'' property was not included.
   */
  ERR_RELOAD_GLOBAL_INDEX_MISSING_REQUIRED_PROPERTY("Unable to create a reload global index task from the provided set of properties because the required ''{0}'' property was not included."),



  /**
   * Entry ''{0}'' cannot be parsed as a restore task because it does not specify the path to the backup directory in which the backup resides.
   */
  ERR_RESTORE_NO_BACKUP_DIRECTORY("Entry ''{0}'' cannot be parsed as a restore task because it does not specify the path to the backup directory in which the backup resides."),



  /**
   * Entry ''{0}'' cannot be parsed as a search task because it has an invalid value of ''{1}'' for the ds-task-search-filter attribute.
   */
  ERR_SEARCH_TASK_ENTRY_INVALID_FILTER("Entry ''{0}'' cannot be parsed as a search task because it has an invalid value of ''{1}'' for the ds-task-search-filter attribute."),



  /**
   * Entry ''{0}'' cannot be parsed as a search task because it has an invalid value of ''{1}'' for the ds-task-search-scope attribute.
   */
  ERR_SEARCH_TASK_ENTRY_INVALID_SCOPE("Entry ''{0}'' cannot be parsed as a search task because it has an invalid value of ''{1}'' for the ds-task-search-scope attribute."),



  /**
   * Entry ''{0}'' cannot be parsed as a search task because it does not have any value for the ds-task-search-base-dn attribute.
   */
  ERR_SEARCH_TASK_ENTRY_NO_BASE_DN("Entry ''{0}'' cannot be parsed as a search task because it does not have any value for the ds-task-search-base-dn attribute."),



  /**
   * Entry ''{0}'' cannot be parsed as a search task because it does not have any value for the ds-task-search-filter attribute.
   */
  ERR_SEARCH_TASK_ENTRY_NO_FILTER("Entry ''{0}'' cannot be parsed as a search task because it does not have any value for the ds-task-search-filter attribute."),



  /**
   * Entry ''{0}'' cannot be parsed as a search task because it does not have any value for the ds-task-search-output-file attribute.
   */
  ERR_SEARCH_TASK_ENTRY_NO_OUTPUT_FILE("Entry ''{0}'' cannot be parsed as a search task because it does not have any value for the ds-task-search-output-file attribute."),



  /**
   * Entry ''{0}'' cannot be parsed as a search task because it does not have any value for the ds-task-search-scope attribute.
   */
  ERR_SEARCH_TASK_ENTRY_NO_SCOPE("Entry ''{0}'' cannot be parsed as a search task because it does not have any value for the ds-task-search-scope attribute."),



  /**
   * The provided value ''{0}'' is not a valid search filter.
   */
  ERR_SEARCH_TASK_INVALID_FILTER_PROPERTY("The provided value ''{0}'' is not a valid search filter."),



  /**
   * The provided value ''{0}'' is not a valid search scope.
   */
  ERR_SEARCH_TASK_INVALID_SCOPE_PROPERTY("The provided value ''{0}'' is not a valid search scope."),



  /**
   * No property was provided to specify the search base DN.
   */
  ERR_SEARCH_TASK_NO_BASE_PROPERTY("No property was provided to specify the search base DN."),



  /**
   * No property was provided to specify the search filter.
   */
  ERR_SEARCH_TASK_NO_FILTER_PROPERTY("No property was provided to specify the search filter."),



  /**
   * No property was provided to specify the output file.
   */
  ERR_SEARCH_TASK_NO_OUTPUT_FILE_PROPERTY("No property was provided to specify the output file."),



  /**
   * No property was provided to specify the search scope.
   */
  ERR_SEARCH_TASK_NO_SCOPE_PROPERTY("No property was provided to specify the search scope."),



  /**
   * Entry ''{0}'' cannot be parsed as a scheduled task because the actual start time value ''{1}'' could not be interpreted as a generalized time:  {2}
   */
  ERR_TASK_CANNOT_PARSE_ACTUAL_START_TIME("Entry ''{0}'' cannot be parsed as a scheduled task because the actual start time value ''{1}'' could not be interpreted as a generalized time:  {2}"),



  /**
   * Entry ''{0}'' contains an invalid value ''{1}'' for attribute {2}.  The value must be either ''true'' or ''false''.
   */
  ERR_TASK_CANNOT_PARSE_BOOLEAN("Entry ''{0}'' contains an invalid value ''{1}'' for attribute {2}.  The value must be either ''true'' or ''false''."),



  /**
   * Entry ''{0}'' cannot be parsed as a scheduled task because the completion time value ''{1}'' could not be interpreted as a generalized time:  {2}
   */
  ERR_TASK_CANNOT_PARSE_COMPLETION_TIME("Entry ''{0}'' cannot be parsed as a scheduled task because the completion time value ''{1}'' could not be interpreted as a generalized time:  {2}"),



  /**
   * Entry ''{0}'' cannot be parsed as a scheduled task because the scheduled start time value ''{1}'' could not be interpreted as a generalized time:  {2}
   */
  ERR_TASK_CANNOT_PARSE_SCHEDULED_START_TIME("Entry ''{0}'' cannot be parsed as a scheduled task because the scheduled start time value ''{1}'' could not be interpreted as a generalized time:  {2}"),



  /**
   * Entry ''{0}'' cannot be parsed as a scheduled task because it has an unrecognized task state ''{1}''.
   */
  ERR_TASK_INVALID_STATE("Entry ''{0}'' cannot be parsed as a scheduled task because it has an unrecognized task state ''{1}''."),



  /**
   * The thread waiting for task ''{0}'' to complete was interrupted.
   */
  ERR_TASK_MANAGER_WAIT_INTERRUPTED("The thread waiting for task ''{0}'' to complete was interrupted."),



  /**
   * No entry for task ''{0}'' exists in the Directory Server.
   */
  ERR_TASK_MANAGER_WAIT_NO_SUCH_TASK("No entry for task ''{0}'' exists in the Directory Server."),



  /**
   * Entry ''{0}'' cannot be parsed as a scheduled task entry because it is missing the ds-task object class.
   */
  ERR_TASK_MISSING_OC("Entry ''{0}'' cannot be parsed as a scheduled task entry because it is missing the ds-task object class."),



  /**
   * Entry ''{0}'' cannot be parsed as a scheduled task because it does not contain a task class name.
   */
  ERR_TASK_NO_CLASS("Entry ''{0}'' cannot be parsed as a scheduled task because it does not contain a task class name."),



  /**
   * Entry ''{0}'' cannot be parsed as a scheduled task because it does not contain a task ID.
   */
  ERR_TASK_NO_ID("Entry ''{0}'' cannot be parsed as a scheduled task because it does not contain a task ID."),



  /**
   * Entry ''{0}'' cannot be parsed as a scheduled task because it does not contain a task state.
   */
  ERR_TASK_NO_STATE("Entry ''{0}'' cannot be parsed as a scheduled task because it does not contain a task state."),



  /**
   * Multiple values were provided for task property ''{0}'', but only a single value is allowed.
   */
  ERR_TASK_PROPERTY_NOT_MULTIVALUED("Multiple values were provided for task property ''{0}'', but only a single value is allowed."),



  /**
   * Task property ''{0}'' contains value ''{1}'' which is not contained in the set of allowed values for that property.
   */
  ERR_TASK_PROPERTY_VALUE_NOT_ALLOWED("Task property ''{0}'' contains value ''{1}'' which is not contained in the set of allowed values for that property."),



  /**
   * Task property ''{0}'' contains a value which cannot be parsed as a Boolean.
   */
  ERR_TASK_PROPERTY_VALUE_NOT_BOOLEAN("Task property ''{0}'' contains a value which cannot be parsed as a Boolean."),



  /**
   * Task property ''{0}'' contains a value which cannot be parsed as a date.
   */
  ERR_TASK_PROPERTY_VALUE_NOT_DATE("Task property ''{0}'' contains a value which cannot be parsed as a date."),



  /**
   * Task property ''{0}'' contains a value which cannot be parsed as a long.
   */
  ERR_TASK_PROPERTY_VALUE_NOT_LONG("Task property ''{0}'' contains a value which cannot be parsed as a long."),



  /**
   * Task property ''{0}'' contains a value which cannot be parsed as a string.
   */
  ERR_TASK_PROPERTY_VALUE_NOT_STRING("Task property ''{0}'' contains a value which cannot be parsed as a string."),



  /**
   * Task property ''{0}'' is required, but no values were provided.
   */
  ERR_TASK_REQUIRED_PROPERTY_WITHOUT_VALUES("Task property ''{0}'' is required, but no values were provided."),



  /**
   * No fully-qualified task class name was provided in task entry {0}.
   */
  ERR_THIRD_PARTY_TASK_NO_CLASS("No fully-qualified task class name was provided in task entry {0}."),



  /**
   * The name of an alert type to add to the set of degraded alert types.
   */
  INFO_ALERT_DESCRIPTION_ADD_DEGRADED("The name of an alert type to add to the set of degraded alert types."),



  /**
   * The name of an alert type to add to the set of unavailable alert types.
   */
  INFO_ALERT_DESCRIPTION_ADD_UNAVAILABLE("The name of an alert type to add to the set of unavailable alert types."),



  /**
   * The message for the administrative alert to generate.  If this is provided, then an alert type must also be provided.
   */
  INFO_ALERT_DESCRIPTION_MESSAGE("The message for the administrative alert to generate.  If this is provided, then an alert type must also be provided."),



  /**
   * The name of an alert type to remove from the set of degraded alert types.
   */
  INFO_ALERT_DESCRIPTION_REMOVE_DEGRADED("The name of an alert type to remove from the set of degraded alert types."),



  /**
   * The name of an alert type to remove from the set of unavailable alert types.
   */
  INFO_ALERT_DESCRIPTION_REMOVE_UNAVAILABLE("The name of an alert type to remove from the set of unavailable alert types."),



  /**
   * The alert type for the administrative alert to generate.  If this is provided, then an alert message must also be provided.
   */
  INFO_ALERT_DESCRIPTION_TYPE("The alert type for the administrative alert to generate.  If this is provided, then an alert message must also be provided."),



  /**
   * Add Degraded Alert Type
   */
  INFO_ALERT_DISPLAY_NAME_ADD_DEGRADED("Add Degraded Alert Type"),



  /**
   * Add Unavailable Alert Type
   */
  INFO_ALERT_DISPLAY_NAME_ADD_UNAVAILABLE("Add Unavailable Alert Type"),



  /**
   * Alert Message
   */
  INFO_ALERT_DISPLAY_NAME_MESSAGE("Alert Message"),



  /**
   * Remove Degraded Alert Type
   */
  INFO_ALERT_DISPLAY_NAME_REMOVE_DEGRADED("Remove Degraded Alert Type"),



  /**
   * Remove Unavailable Alert Type
   */
  INFO_ALERT_DISPLAY_NAME_REMOVE_UNAVAILABLE("Remove Unavailable Alert Type"),



  /**
   * Alert Type
   */
  INFO_ALERT_DISPLAY_NAME_TYPE("Alert Type"),



  /**
   * The backend IDs of the backends in which data should be audited.  If no backend IDs are specified, then the audit will examine data in all backends that support this capability.
   */
  INFO_AUDIT_DATA_SECURITY_DESCRIPTION_BACKEND_ID("The backend IDs of the backends in which data should be audited.  If no backend IDs are specified, then the audit will examine data in all backends that support this capability."),



  /**
   * The names of the auditors to be excluded when examining the security of the data.  If excluded auditors are specified, then you must not also specify included auditors.  If neither included nor excluded auditors are provided, then the audit will use all enabled auditors configured in the server.
   */
  INFO_AUDIT_DATA_SECURITY_DESCRIPTION_EXCLUDE_AUDITOR("The names of the auditors to be excluded when examining the security of the data.  If excluded auditors are specified, then you must not also specify included auditors.  If neither included nor excluded auditors are provided, then the audit will use all enabled auditors configured in the server."),



  /**
   * The names of the auditors to be used in the course of examining the security of the data.  If included auditors are specified, then you must not also specify excluded auditors.  If neither included nor excluded auditors are provided, then the audit will use all enabled auditors configured in the server.
   */
  INFO_AUDIT_DATA_SECURITY_DESCRIPTION_INCLUDE_AUDITOR("The names of the auditors to be used in the course of examining the security of the data.  If included auditors are specified, then you must not also specify excluded auditors.  If neither included nor excluded auditors are provided, then the audit will use all enabled auditors configured in the server."),



  /**
   * The path to the directory on the server filesystem in which report output files should be written.  If this is not specified, then a default location will be used.
   */
  INFO_AUDIT_DATA_SECURITY_DESCRIPTION_OUTPUT_DIR("The path to the directory on the server filesystem in which report output files should be written.  If this is not specified, then a default location will be used."),



  /**
   * A set of filters that may be used to indicate which entries should be examined during the audit.  If no report filters are specified, then all entries in the selected backends will be included.
   */
  INFO_AUDIT_DATA_SECURITY_DESCRIPTION_REPORT_FILTER("A set of filters that may be used to indicate which entries should be examined during the audit.  If no report filters are specified, then all entries in the selected backends will be included."),



  /**
   * Audit Backend IDs
   */
  INFO_AUDIT_DATA_SECURITY_DISPLAY_NAME_BACKEND_ID("Audit Backend IDs"),



  /**
   * Excluded Auditors
   */
  INFO_AUDIT_DATA_SECURITY_DISPLAY_NAME_EXCLUDE_AUDITOR("Excluded Auditors"),



  /**
   * Included Auditors
   */
  INFO_AUDIT_DATA_SECURITY_DISPLAY_NAME_INCLUDE_AUDITOR("Included Auditors"),



  /**
   * Output Directory
   */
  INFO_AUDIT_DATA_SECURITY_DISPLAY_NAME_OUTPUT_DIR("Output Directory"),



  /**
   * Report Filters
   */
  INFO_AUDIT_DATA_SECURITY_DISPLAY_NAME_REPORT_FILTER("Report Filters"),



  /**
   * Indicates whether the data in the specified LDIF files should be appended to the existing data rather than replacing it.
   */
  INFO_DESCRIPTION_APPEND_TO_DB("Indicates whether the data in the specified LDIF files should be appended to the existing data rather than replacing it."),



  /**
   * Indicates whether to append to the specified LDIF file if it already exists.  Otherwise, it will be overwritten.
   */
  INFO_DESCRIPTION_APPEND_TO_LDIF("Indicates whether to append to the specified LDIF file if it already exists.  Otherwise, it will be overwritten."),



  /**
   * The backend ID of the backend to be archived.  Multiple backend IDs may be specified as separate values.  If no backend IDs are provided, then all supported backends will be archived.
   */
  INFO_DESCRIPTION_BACKEND_ID_BACKUP("The backend ID of the backend to be archived.  Multiple backend IDs may be specified as separate values.  If no backend IDs are provided, then all supported backends will be archived."),



  /**
   * The backend ID of the backend from which the data is to be exported.
   */
  INFO_DESCRIPTION_BACKEND_ID_EXPORT("The backend ID of the backend from which the data is to be exported."),



  /**
   * The backend ID of the backend into which the data is to be imported.  If this is not specified, then one or more include branches must be defined.
   */
  INFO_DESCRIPTION_BACKEND_ID_IMPORT("The backend ID of the backend into which the data is to be imported.  If this is not specified, then one or more include branches must be defined."),



  /**
   * The path to the directory in which the backup files should be placed.  If multiple backends are to be archived, then this should be the parent directory of the backup directories for each backend.
   */
  INFO_DESCRIPTION_BACKUP_DIRECTORY_BACKUP("The path to the directory in which the backup files should be placed.  If multiple backends are to be archived, then this should be the parent directory of the backup directories for each backend."),



  /**
   * The path to the directory containing the backup to be restored.
   */
  INFO_DESCRIPTION_BACKUP_DIRECTORY_RESTORE("The path to the directory containing the backup to be restored."),



  /**
   * The backup ID to use for the backup.  If no backup ID is specified, then the server will generate one.
   */
  INFO_DESCRIPTION_BACKUP_ID_BACKUP("The backup ID to use for the backup.  If no backup ID is specified, then the server will generate one."),



  /**
   * The backup ID of the backup that should be restored.  If this is not provided, then the most recent backup contained in the specified backup directory will be used.
   */
  INFO_DESCRIPTION_BACKUP_ID_RESTORE("The backup ID of the backup that should be restored.  If this is not provided, then the most recent backup contained in the specified backup directory will be used."),



  /**
   * The base DN of the backend below which the index data should be rebuilt.
   */
  INFO_DESCRIPTION_BASE_DN_REBUILD("The base DN of the backend below which the index data should be rebuilt."),



  /**
   * Indicates whether to clear all data in the backend when performing an import and one or more include branches is specified.  If this is ''false'', then only data below the specified include branch(es) will be cleared, and data below other base DNs will be preserved.
   */
  INFO_DESCRIPTION_CLEAR_BACKEND("Indicates whether to clear all data in the backend when performing an import and one or more include branches is specified.  If this is ''false'', then only data below the specified include branch(es) will be cleared, and data below other base DNs will be preserved."),



  /**
   * Indicates whether the contents of the backup should be compressed.
   */
  INFO_DESCRIPTION_COMPRESS_BACKUP("Indicates whether the contents of the backup should be compressed."),



  /**
   * Indicates whether to compress the exported LDIF data.
   */
  INFO_DESCRIPTION_COMPRESS_EXPORT("Indicates whether to compress the exported LDIF data."),



  /**
   * The task ID of another task that must complete before this task will be eligible to start running.  If this is not provided, then the task will be eligible to start at any time.
   */
  INFO_DESCRIPTION_DEPENDENCY_ID("The task ID of another task that must complete before this task will be eligible to start running.  If this is not provided, then the task will be eligible to start at any time."),



  /**
   * The connection ID for the client connection to be disconnected.
   */
  INFO_DESCRIPTION_DISCONNECT_CONN_ID("The connection ID for the client connection to be disconnected."),



  /**
   * A message that provides additional information about the disconnection.  If notification is to be sent to the client, then this message will be included in that notification.
   */
  INFO_DESCRIPTION_DISCONNECT_MESSAGE("A message that provides additional information about the disconnection.  If notification is to be sent to the client, then this message will be included in that notification."),



  /**
   * Indicates whether to send the client a notice of disconnection message before terminating the connection.
   */
  INFO_DESCRIPTION_DISCONNECT_NOTIFY("Indicates whether to send the client a notice of disconnection message before terminating the connection."),



  /**
   * Indicates whether the contents of the backup should be encrypted.
   */
  INFO_DESCRIPTION_ENCRYPT_BACKUP("Indicates whether the contents of the backup should be encrypted."),



  /**
   * Indicates whether to encrypt the exported LDIF data.
   */
  INFO_DESCRIPTION_ENCRYPT_EXPORT("Indicates whether to encrypt the exported LDIF data."),



  /**
   * An optional reason for putting the server into lockdown mode.
   */
  INFO_DESCRIPTION_ENTER_LOCKDOWN_REASON("An optional reason for putting the server into lockdown mode."),



  /**
   * The name of an attribute that should be excluded from exported entries.  If this is not provided, then all attributes will be included in the export.  Otherwise, none of only the specified set of attributes will be included.
   */
  INFO_DESCRIPTION_EXCLUDE_ATTRIBUTE_EXPORT("The name of an attribute that should be excluded from exported entries.  If this is not provided, then all attributes will be included in the export.  Otherwise, none of only the specified set of attributes will be included."),



  /**
   * The name of an attribute that should be excluded from imported entries.  If this is not provided, then all attributes will be included.  Otherwise, all attributes other than the excluded attributes will be included.
   */
  INFO_DESCRIPTION_EXCLUDE_ATTRIBUTE_IMPORT("The name of an attribute that should be excluded from imported entries.  If this is not provided, then all attributes will be included.  Otherwise, all attributes other than the excluded attributes will be included."),



  /**
   * The base DN of a branch that is to be excluded from the export.  If this is not provided, then all data in the backend will be eligible for inclusion in the export.  Otherwise, only data that does not exist below any of the exclude branches will be included.
   */
  INFO_DESCRIPTION_EXCLUDE_BRANCH_EXPORT("The base DN of a branch that is to be excluded from the export.  If this is not provided, then all data in the backend will be eligible for inclusion in the export.  Otherwise, only data that does not exist below any of the exclude branches will be included."),



  /**
   * The base DN of a branch to exclude from the import.  If no exclude branches are provided, then all data in the provided LDIF files will be imported.  Otherwise, only data that does not exist below one of the specified exclude branches will be imported.
   */
  INFO_DESCRIPTION_EXCLUDE_BRANCH_IMPORT("The base DN of a branch to exclude from the import.  If no exclude branches are provided, then all data in the provided LDIF files will be imported.  Otherwise, only data that does not exist below one of the specified exclude branches will be imported."),



  /**
   * A filter that will be applied to an entry to determine whether it should be excluded from the export.  If this is not provided, then all entries will be eligible for inclusion in the export.  Otherwise, no entries that match one of the provided exclude filters will be included.
   */
  INFO_DESCRIPTION_EXCLUDE_FILTER_EXPORT("A filter that will be applied to an entry to determine whether it should be excluded from the export.  If this is not provided, then all entries will be eligible for inclusion in the export.  Otherwise, no entries that match one of the provided exclude filters will be included."),



  /**
   * A filter that will be applied to an entry to determine whether it should be excluded from the import.  If this is not provided, then no entries will be excluded from the import.
   */
  INFO_DESCRIPTION_EXCLUDE_FILTER_IMPORT("A filter that will be applied to an entry to determine whether it should be excluded from the import.  If this is not provided, then no entries will be excluded from the import."),



  /**
   * Specifies the action to take with this task if any task on which it depends does not complete successfully.  Allowed values include ''cancel'', ''disable'', or ''process''.  If this is not provided, then the task will be disabled if any of the tasks on which it depends does not complete successfully.
   */
  INFO_DESCRIPTION_FAILED_DEPENDENCY_ACTION("Specifies the action to take with this task if any task on which it depends does not complete successfully.  Allowed values include ''cancel'', ''disable'', or ''process''.  If this is not provided, then the task will be disabled if any of the tasks on which it depends does not complete successfully."),



  /**
   * An argument to provide to the scripted task.  It should be in the form name=value.
   */
  INFO_DESCRIPTION_GROOVY_SCRIPTED_TASK_ARG("An argument to provide to the scripted task.  It should be in the form name=value."),



  /**
   * The fully-qualified name of the Groovy class providing the logic for the scripted task.
   */
  INFO_DESCRIPTION_GROOVY_SCRIPTED_TASK_CLASS("The fully-qualified name of the Groovy class providing the logic for the scripted task."),



  /**
   * Indicates whether to calculate a hash of the backup contents, which can be used to verify the integrity of the backup.
   */
  INFO_DESCRIPTION_HASH_BACKUP("Indicates whether to calculate a hash of the backup contents, which can be used to verify the integrity of the backup."),



  /**
   * The name of an attribute that should be included in exported entries.  If this is not provided, then all attributes will be included in the export.  Otherwise, only the specified set of attributes will be included.
   */
  INFO_DESCRIPTION_INCLUDE_ATTRIBUTE_EXPORT("The name of an attribute that should be included in exported entries.  If this is not provided, then all attributes will be included in the export.  Otherwise, only the specified set of attributes will be included."),



  /**
   * The name of an attribute that should be included in imported entries.  If this is not provided, then all attributes will be included.  Otherwise, only the specified attributes will be included.
   */
  INFO_DESCRIPTION_INCLUDE_ATTRIBUTE_IMPORT("The name of an attribute that should be included in imported entries.  If this is not provided, then all attributes will be included.  Otherwise, only the specified attributes will be included."),



  /**
   * The base DN of a branch that is to be included in the export.  If this is not provided, then all data in the backend will be eligible for inclusion in the export.  Otherwise, only data that exists below one of the include branches will be included.
   */
  INFO_DESCRIPTION_INCLUDE_BRANCH_EXPORT("The base DN of a branch that is to be included in the export.  If this is not provided, then all data in the backend will be eligible for inclusion in the export.  Otherwise, only data that exists below one of the include branches will be included."),



  /**
   * The base DN of a branch to include in the import.  If no include branches are provided, then a backend ID must be given, and all data in the provided LDIF files will be imported.  Otherwise, only data that exists below one of the specified include branches will be imported.
   */
  INFO_DESCRIPTION_INCLUDE_BRANCH_IMPORT("The base DN of a branch to include in the import.  If no include branches are provided, then a backend ID must be given, and all data in the provided LDIF files will be imported.  Otherwise, only data that exists below one of the specified include branches will be imported."),



  /**
   * A filter that will be applied to an entry to determine whether it should be included in the export.  If this is not provided, then all entries will be eligible for inclusion in the export.  Otherwise, only entries that match one of the provided include filters will be included.
   */
  INFO_DESCRIPTION_INCLUDE_FILTER_EXPORT("A filter that will be applied to an entry to determine whether it should be included in the export.  If this is not provided, then all entries will be eligible for inclusion in the export.  Otherwise, only entries that match one of the provided include filters will be included."),



  /**
   * A filter that will be applied to an entry to determine whether it should be included in the import.  If this is not provided, then all entries will be included in the import.
   */
  INFO_DESCRIPTION_INCLUDE_FILTER_IMPORT("A filter that will be applied to an entry to determine whether it should be included in the import.  If this is not provided, then all entries will be included in the import."),



  /**
   * Indicates whether to attempt an incremental backup rather than a full backup.  An incremental backup includes only that information which has changed since the previous backup.  Note that if the associated backend does not support incremental backups, then a full backup will be performed.
   */
  INFO_DESCRIPTION_INCREMENTAL("Indicates whether to attempt an incremental backup rather than a full backup.  An incremental backup includes only that information which has changed since the previous backup.  Note that if the associated backend does not support incremental backups, then a full backup will be performed."),



  /**
   * The backup ID for the previous backup on which to base an incremental backup.  If this is not provided, then the server will base the incremental backup on the last available backup in the backup directory.  This will be ignored for non-incremental backups.
   */
  INFO_DESCRIPTION_INCREMENTAL_BASE_ID("The backup ID for the previous backup on which to base an incremental backup.  If this is not provided, then the server will base the incremental backup on the last available backup in the backup directory.  This will be ignored for non-incremental backups."),



  /**
   * The name of the index to be rebuilt.  For attribute indexes, this is the name of the associated attribute.  For VLV indexes, this is the name of the VLV index.  Multiple indexes can be rebuilt by providing multiple index names as separate values.
   */
  INFO_DESCRIPTION_INDEX_REBUILD("The name of the index to be rebuilt.  For attribute indexes, this is the name of the associated attribute.  For VLV indexes, this is the name of the VLV index.  Multiple indexes can be rebuilt by providing multiple index names as separate values."),



  /**
   * Indicates whether the LDIF data to be imported is compressed.
   */
  INFO_DESCRIPTION_IS_COMPRESSED_IMPORT("Indicates whether the LDIF data to be imported is compressed."),



  /**
   * Indicates whether the LDIF data to be imported is encrypted.
   */
  INFO_DESCRIPTION_IS_ENCRYPTED_IMPORT("Indicates whether the LDIF data to be imported is encrypted."),



  /**
   * The path to the LDIF file to which the exported data is to be written.
   */
  INFO_DESCRIPTION_LDIF_FILE_EXPORT("The path to the LDIF file to which the exported data is to be written."),



  /**
   * Specifies the path to the LDIF file containing the data to be imported.  Multiple LDIF files can be specified as separate values, and the data contained in them will be processed in the order they were specified.
   */
  INFO_DESCRIPTION_LDIF_FILE_IMPORT("Specifies the path to the LDIF file containing the data to be imported.  Multiple LDIF files can be specified as separate values, and the data contained in them will be processed in the order they were specified."),



  /**
   * An optional reason for taking the server out of lockdown mode.
   */
  INFO_DESCRIPTION_LEAVE_LOCKDOWN_REASON("An optional reason for taking the server out of lockdown mode."),



  /**
   * The maximum number of concurrent threads to use when rebuilding index data.  A value less than or equal to zero indicates that there should be no limit to the number of threads that may be used.
   */
  INFO_DESCRIPTION_MAX_THREADS_REBUILD("The maximum number of concurrent threads to use when rebuilding index data.  A value less than or equal to zero indicates that there should be no limit to the number of threads that may be used."),



  /**
   * The e-mail address of an individual that should be sent a notification message whenever this task completes.  The notification message will be sent regardless of whether the task completes successfully.
   */
  INFO_DESCRIPTION_NOTIFY_ON_COMPLETION("The e-mail address of an individual that should be sent a notification message whenever this task completes.  The notification message will be sent regardless of whether the task completes successfully."),



  /**
   * The e-mail address of an individual that should be sent a notification message if this task is unable to complete successfully.  No message will be sent to this address if the task does complete successfully.
   */
  INFO_DESCRIPTION_NOTIFY_ON_ERROR("The e-mail address of an individual that should be sent a notification message if this task is unable to complete successfully.  No message will be sent to this address if the task does complete successfully."),



  /**
   * Indicates whether to overwrite an existing reject file if it exists.  Otherwise, the server will append to the file.
   */
  INFO_DESCRIPTION_OVERWRITE_REJECTS("Indicates whether to overwrite an existing reject file if it exists.  Otherwise, the server will append to the file."),



  /**
   * The backend ID for the backend in which the re-encode processing is to be performed.
   */
  INFO_DESCRIPTION_REENCODE_BACKEND_ID("The backend ID for the backend in which the re-encode processing is to be performed."),



  /**
   * The base DN of a branch to exclude from re-encode processing.
   */
  INFO_DESCRIPTION_REENCODE_EXCLUDE_BRANCH("The base DN of a branch to exclude from re-encode processing."),



  /**
   * A filter to use to identify entries to exclude from re-encode processing.
   */
  INFO_DESCRIPTION_REENCODE_EXCLUDE_FILTER("A filter to use to identify entries to exclude from re-encode processing."),



  /**
   * The base DN of a branch to include in re-encode processing.
   */
  INFO_DESCRIPTION_REENCODE_INCLUDE_BRANCH("The base DN of a branch to include in re-encode processing."),



  /**
   * A filter to use to identify entries to include in re-encode processing.
   */
  INFO_DESCRIPTION_REENCODE_INCLUDE_FILTER("A filter to use to identify entries to include in re-encode processing."),



  /**
   * The maximum number of entries to be re-encoded per second.
   */
  INFO_DESCRIPTION_REENCODE_MAX_ENTRIES_PER_SECOND("The maximum number of entries to be re-encoded per second."),



  /**
   * Indicates whether to skip re-encode processing for entries that are stored completely uncached.
   */
  INFO_DESCRIPTION_REENCODE_SKIP_FULLY_UNCACHED("Indicates whether to skip re-encode processing for entries that are stored completely uncached."),



  /**
   * Indicates whether to skip re-encode processing for entries that are stored with a mix of cached and uncached attributes.
   */
  INFO_DESCRIPTION_REENCODE_SKIP_PARTIALLY_UNCACHED("Indicates whether to skip re-encode processing for entries that are stored with a mix of cached and uncached attributes."),



  /**
   * The path to a file to which information about rejected entries should be written.  If this is not specified, then no reject file will be written.
   */
  INFO_DESCRIPTION_REJECT_FILE("The path to a file to which information about rejected entries should be written.  If this is not specified, then no reject file will be written."),



  /**
   * The name(s) of the attributes for which to reload index information.  If this is not provided, then all indexes will be reloaded.
   */
  INFO_DESCRIPTION_RELOAD_GLOBAL_INDEX_ATTR_NAME("The name(s) of the attributes for which to reload index information.  If this is not provided, then all indexes will be reloaded."),



  /**
   * Indicates whether to perform the reload in a background thread so that the task completes immediately.
   */
  INFO_DESCRIPTION_RELOAD_GLOBAL_INDEX_BACKGROUND("Indicates whether to perform the reload in a background thread so that the task completes immediately."),



  /**
   * The base DN of the entry-balancing request processor for which to reload global index information.  This must be specified.
   */
  INFO_DESCRIPTION_RELOAD_GLOBAL_INDEX_BASE_DN("The base DN of the entry-balancing request processor for which to reload global index information.  This must be specified."),



  /**
   * An optional target maximum rate at which entries should be reloaded.  A value of zero indicates no limit.  If this is not specified, then the rate limit will be determined from the Directory Proxy Server configuration.
   */
  INFO_DESCRIPTION_RELOAD_GLOBAL_INDEX_MAX_ENTRIES_PER_SECOND("An optional target maximum rate at which entries should be reloaded.  A value of zero indicates no limit.  If this is not specified, then the rate limit will be determined from the Directory Proxy Server configuration."),



  /**
   * Indicates whether to retrieve the index information from backend Directory Server instances rather than a peer Directory Proxy Server instance.
   */
  INFO_DESCRIPTION_RELOAD_GLOBAL_INDEX_RELOAD_FROM_DS("Indicates whether to retrieve the index information from backend Directory Server instances rather than a peer Directory Proxy Server instance."),



  /**
   * Indicates whether to replace an existing entry if it is contained in the LDIF file when appending to the database.  This is ignored when not operating in append mode.
   */
  INFO_DESCRIPTION_REPLACE_EXISTING("Indicates whether to replace an existing entry if it is contained in the LDIF file when appending to the database.  This is ignored when not operating in append mode."),



  /**
   * Indicates that the server should be restarted instead of shut down.
   */
  INFO_DESCRIPTION_RESTART_SERVER("Indicates that the server should be restarted instead of shut down."),



  /**
   * The earliest time that this task should be allowed to start running.  If it is specified, then it must be in generalized time format (e.g., 'YYYYMMDDhhmmssZ' for UTC or 'YYYYMMDDhhmmss+0500' to specify a UTC offset).  If this is not provided, then the task will be eligible to start at any time.
   */
  INFO_DESCRIPTION_SCHEDULED_START_TIME("The earliest time that this task should be allowed to start running.  If it is specified, then it must be in generalized time format (e.g., 'YYYYMMDDhhmmssZ' for UTC or 'YYYYMMDDhhmmss+0500' to specify a UTC offset).  If this is not provided, then the task will be eligible to start at any time."),



  /**
   * The name (without path information) of the file whose contents should be added to the server schema.  The file must exist in the server''s schema directory.
   */
  INFO_DESCRIPTION_SCHEMA_FILE("The name (without path information) of the file whose contents should be added to the server schema.  The file must exist in the server''s schema directory."),



  /**
   * A human-readable message that may be used to provide information about the reason for the shutdown.
   */
  INFO_DESCRIPTION_SHUTDOWN_MESSAGE("A human-readable message that may be used to provide information about the reason for the shutdown."),



  /**
   * Indicates whether to include a digital signature at the end of the export data which can be used to ensure that data has not been altered.
   */
  INFO_DESCRIPTION_SIGN_EXPORT("Indicates whether to include a digital signature at the end of the export data which can be used to ensure that data has not been altered."),



  /**
   * Indicates whether the backup hash should be digitally signed to ensure that it cannot be altered.
   */
  INFO_DESCRIPTION_SIGN_HASH_BACKUP("Indicates whether the backup hash should be digitally signed to ensure that it cannot be altered."),



  /**
   * Indicates whether the server should skip schema validation for the entries being imported.
   */
  INFO_DESCRIPTION_SKIP_SCHEMA_VALIDATION("Indicates whether the server should skip schema validation for the entries being imported."),



  /**
   * Indicates whether the server should strip illegal trailing spaces from LDIF records rather than rejecting those records.
   */
  INFO_DESCRIPTION_STRIP_TRAILING_SPACES("Indicates whether the server should strip illegal trailing spaces from LDIF records rather than rejecting those records."),



  /**
   * The unique identifier for the task.  It must not already be in use by any task available in the Directory Server.  If this is not provided, then a UUID will be generated for use as the task ID.
   */
  INFO_DESCRIPTION_TASK_ID("The unique identifier for the task.  It must not already be in use by any task available in the Directory Server.  If this is not provided, then a UUID will be generated for use as the task ID."),



  /**
   * An argument to provide to the third-party task.  It should be in the form name=value.
   */
  INFO_DESCRIPTION_THIRD_PARTY_TASK_ARG("An argument to provide to the third-party task.  It should be in the form name=value."),



  /**
   * The fully-qualified name of the Java class providing the logic for the third-party task.
   */
  INFO_DESCRIPTION_THIRD_PARTY_TASK_CLASS("The fully-qualified name of the Java class providing the logic for the third-party task."),



  /**
   * Indicates whether the server should attempt to verify whether it should be possible to restore the specified backup without actually performing the restore.
   */
  INFO_DESCRIPTION_VERIFY_ONLY("Indicates whether the server should attempt to verify whether it should be possible to restore the specified backup without actually performing the restore."),



  /**
   * The column at which long lines should be wrapped when writing the LDIF data.  If this is not provided, or if the provided value is less than or equal to zero, then no wrapping will be performed.
   */
  INFO_DESCRIPTION_WRAP_COLUMN("The column at which long lines should be wrapped when writing the LDIF data.  If this is not provided, or if the provided value is less than or equal to zero, then no wrapping will be performed."),



  /**
   * Append to Existing Data
   */
  INFO_DISPLAY_NAME_APPEND_TO_DB("Append to Existing Data"),



  /**
   * Append to LDIF File
   */
  INFO_DISPLAY_NAME_APPEND_TO_LDIF("Append to LDIF File"),



  /**
   * Backend ID
   */
  INFO_DISPLAY_NAME_BACKEND_ID("Backend ID"),



  /**
   * Backup Directory Path
   */
  INFO_DISPLAY_NAME_BACKUP_DIRECTORY("Backup Directory Path"),



  /**
   * Backup ID
   */
  INFO_DISPLAY_NAME_BACKUP_ID("Backup ID"),



  /**
   * Backend Base DN
   */
  INFO_DISPLAY_NAME_BASE_DN_REBUILD("Backend Base DN"),



  /**
   * Clear the Entire Backend
   */
  INFO_DISPLAY_NAME_CLEAR_BACKEND("Clear the Entire Backend"),



  /**
   * Compress
   */
  INFO_DISPLAY_NAME_COMPRESS("Compress"),



  /**
   * Depends on Task
   */
  INFO_DISPLAY_NAME_DEPENDENCY_ID("Depends on Task"),



  /**
   * Connection ID
   */
  INFO_DISPLAY_NAME_DISCONNECT_CONN_ID("Connection ID"),



  /**
   * Disconnect Message
   */
  INFO_DISPLAY_NAME_DISCONNECT_MESSAGE("Disconnect Message"),



  /**
   * Notify Client Before Disconnecting
   */
  INFO_DISPLAY_NAME_DISCONNECT_NOTIFY("Notify Client Before Disconnecting"),



  /**
   * Encrypt
   */
  INFO_DISPLAY_NAME_ENCRYPT("Encrypt"),



  /**
   * Reason
   */
  INFO_DISPLAY_NAME_ENTER_LOCKDOWN_REASON("Reason"),



  /**
   * Exclude Attribute
   */
  INFO_DISPLAY_NAME_EXCLUDE_ATTRIBUTE("Exclude Attribute"),



  /**
   * Include Branch DN
   */
  INFO_DISPLAY_NAME_EXCLUDE_BRANCH("Include Branch DN"),



  /**
   * Exclude Filter
   */
  INFO_DISPLAY_NAME_EXCLUDE_FILTER("Exclude Filter"),



  /**
   * Failed Dependency Action
   */
  INFO_DISPLAY_NAME_FAILED_DEPENDENCY_ACTION("Failed Dependency Action"),



  /**
   * Groovy-Scripted Task Argument
   */
  INFO_DISPLAY_NAME_GROOVY_SCRIPTED_TASK_ARG("Groovy-Scripted Task Argument"),



  /**
   * Groovy-Scripted Task Class Name
   */
  INFO_DISPLAY_NAME_GROOVY_SCRIPTED_TASK_CLASS("Groovy-Scripted Task Class Name"),



  /**
   * Calculate Hash
   */
  INFO_DISPLAY_NAME_HASH("Calculate Hash"),



  /**
   * Include Attribute
   */
  INFO_DISPLAY_NAME_INCLUDE_ATTRIBUTE("Include Attribute"),



  /**
   * Include Branch DN
   */
  INFO_DISPLAY_NAME_INCLUDE_BRANCH("Include Branch DN"),



  /**
   * Include Filter
   */
  INFO_DISPLAY_NAME_INCLUDE_FILTER("Include Filter"),



  /**
   * Incremental Backup
   */
  INFO_DISPLAY_NAME_INCREMENTAL("Incremental Backup"),



  /**
   * Incremental Base ID
   */
  INFO_DISPLAY_NAME_INCREMENTAL_BASE_ID("Incremental Base ID"),



  /**
   * Index Name
   */
  INFO_DISPLAY_NAME_INDEX_REBUILD("Index Name"),



  /**
   * LDIF Data Is Compressed
   */
  INFO_DISPLAY_NAME_IS_COMPRESSED_IMPORT("LDIF Data Is Compressed"),



  /**
   * LDIF Data Is Encrypted
   */
  INFO_DISPLAY_NAME_IS_ENCRYPTED_IMPORT("LDIF Data Is Encrypted"),



  /**
   * LDIF File Path
   */
  INFO_DISPLAY_NAME_LDIF_FILE("LDIF File Path"),



  /**
   * Reason
   */
  INFO_DISPLAY_NAME_LEAVE_LOCKDOWN_REASON("Reason"),



  /**
   * Maximum Concurrent Rebuild Threads
   */
  INFO_DISPLAY_NAME_MAX_THREADS_REBUILD("Maximum Concurrent Rebuild Threads"),



  /**
   * Notify on Completion
   */
  INFO_DISPLAY_NAME_NOTIFY_ON_COMPLETION("Notify on Completion"),



  /**
   * Notify on Error
   */
  INFO_DISPLAY_NAME_NOTIFY_ON_ERROR("Notify on Error"),



  /**
   * Overwrite Existing Reject File
   */
  INFO_DISPLAY_NAME_OVERWRITE_REJECTS("Overwrite Existing Reject File"),



  /**
   * Backend ID
   */
  INFO_DISPLAY_NAME_REENCODE_BACKEND_ID("Backend ID"),



  /**
   * Exclude Branch
   */
  INFO_DISPLAY_NAME_REENCODE_EXCLUDE_BRANCH("Exclude Branch"),



  /**
   * Exclude Filter
   */
  INFO_DISPLAY_NAME_REENCODE_EXCLUDE_FILTER("Exclude Filter"),



  /**
   * Include Branch
   */
  INFO_DISPLAY_NAME_REENCODE_INCLUDE_BRANCH("Include Branch"),



  /**
   * Include Filter
   */
  INFO_DISPLAY_NAME_REENCODE_INCLUDE_FILTER("Include Filter"),



  /**
   * Maximum Entries to Re-Encode Per Second
   */
  INFO_DISPLAY_NAME_REENCODE_MAX_ENTRIES_PER_SECOND("Maximum Entries to Re-Encode Per Second"),



  /**
   * Skip Fully Uncached Entries
   */
  INFO_DISPLAY_NAME_REENCODE_SKIP_FULLY_UNCACHED("Skip Fully Uncached Entries"),



  /**
   * Skip Partially Uncached Entries
   */
  INFO_DISPLAY_NAME_REENCODE_SKIP_PARTIALLY_UNCACHED("Skip Partially Uncached Entries"),



  /**
   * Reject File Path
   */
  INFO_DISPLAY_NAME_REJECT_FILE("Reject File Path"),



  /**
   * Attribute Name
   */
  INFO_DISPLAY_NAME_RELOAD_GLOBAL_INDEX_ATTR_NAME("Attribute Name"),



  /**
   * Reload in a Background Thread
   */
  INFO_DISPLAY_NAME_RELOAD_GLOBAL_INDEX_BACKGROUND("Reload in a Background Thread"),



  /**
   * Entry-Balancing Request Processor Base DN
   */
  INFO_DISPLAY_NAME_RELOAD_GLOBAL_INDEX_BASE_DN("Entry-Balancing Request Processor Base DN"),



  /**
   * Maximum Reload Rate (Entries/Second)
   */
  INFO_DISPLAY_NAME_RELOAD_GLOBAL_INDEX_MAX_ENTRIES_PER_SECOND("Maximum Reload Rate (Entries/Second)"),



  /**
   * Reload from Backend Directory Servers
   */
  INFO_DISPLAY_NAME_RELOAD_GLOBAL_INDEX_RELOAD_FROM_DS("Reload from Backend Directory Servers"),



  /**
   * Replace Existing Entries when Appending
   */
  INFO_DISPLAY_NAME_REPLACE_EXISTING("Replace Existing Entries when Appending"),



  /**
   * Restart Instead of Shut Down
   */
  INFO_DISPLAY_NAME_RESTART_SERVER("Restart Instead of Shut Down"),



  /**
   * Scheduled Start Time
   */
  INFO_DISPLAY_NAME_SCHEDULED_START_TIME("Scheduled Start Time"),



  /**
   * Schema File Name
   */
  INFO_DISPLAY_NAME_SCHEMA_FILE("Schema File Name"),



  /**
   * Shutdown Message
   */
  INFO_DISPLAY_NAME_SHUTDOWN_MESSAGE("Shutdown Message"),



  /**
   * Sign Export
   */
  INFO_DISPLAY_NAME_SIGN("Sign Export"),



  /**
   * Sign Hash
   */
  INFO_DISPLAY_NAME_SIGN_HASH("Sign Hash"),



  /**
   * Skip Schema Validation
   */
  INFO_DISPLAY_NAME_SKIP_SCHEMA_VALIDATION("Skip Schema Validation"),



  /**
   * Strip Trailing Spaces
   */
  INFO_DISPLAY_NAME_STRIP_TRAILING_SPACES("Strip Trailing Spaces"),



  /**
   * Task ID
   */
  INFO_DISPLAY_NAME_TASK_ID("Task ID"),



  /**
   * Third-Party Task Argument
   */
  INFO_DISPLAY_NAME_THIRD_PARTY_TASK_ARG("Third-Party Task Argument"),



  /**
   * Third-Party Task Class Name
   */
  INFO_DISPLAY_NAME_THIRD_PARTY_TASK_CLASS("Third-Party Task Class Name"),



  /**
   * Verify Without Restoring
   */
  INFO_DISPLAY_NAME_VERIFY_ONLY("Verify Without Restoring"),



  /**
   * Wrap Column
   */
  INFO_DISPLAY_NAME_WRAP_COLUMN("Wrap Column"),



  /**
   * The backend ID for the backend whose contents should be examined.
   */
  INFO_DUMP_DB_DESCRIPTION_BACKEND_ID("The backend ID for the backend whose contents should be examined."),



  /**
   * Backend ID
   */
  INFO_DUMP_DB_DISPLAY_NAME_BACKEND_ID("Backend ID"),



  /**
   * The DN of the user as whom the search should be processed.  If this is not specified, then the search will be processed as an internal root user.
   */
  INFO_SEARCH_TASK_DESCRIPTION_AUTHZ_DN("The DN of the user as whom the search should be processed.  If this is not specified, then the search will be processed as an internal root user."),



  /**
   * The base DN to use for the search.
   */
  INFO_SEARCH_TASK_DESCRIPTION_BASE_DN("The base DN to use for the search."),



  /**
   * The filter to use for the search.
   */
  INFO_SEARCH_TASK_DESCRIPTION_FILTER("The filter to use for the search."),



  /**
   * The path (on the server filesystem) to the LDIF file to be written with entries matching the search criteria.
   */
  INFO_SEARCH_TASK_DESCRIPTION_NAME_OUTPUT_FILE("The path (on the server filesystem) to the LDIF file to be written with entries matching the search criteria."),



  /**
   * The name of an attribute to include in matching entries, or a grouping token like '*' (for all user attributes), '+' (for all operational attributes), or '@inetOrgPerson' (for all attributes in the inetOrgPerson object class).  If this is not provided then all user attributes will be selected.
   */
  INFO_SEARCH_TASK_DESCRIPTION_RETURN_ATTR("The name of an attribute to include in matching entries, or a grouping token like '*' (for all user attributes), '+' (for all operational attributes), or '@inetOrgPerson' (for all attributes in the inetOrgPerson object class).  If this is not provided then all user attributes will be selected."),



  /**
   * The scope to use for the search.  The value must be one of 'base', 'one', 'sub', or 'subordinate'.
   */
  INFO_SEARCH_TASK_DESCRIPTION_SCOPE("The scope to use for the search.  The value must be one of 'base', 'one', 'sub', or 'subordinate'."),



  /**
   * Authorization DN
   */
  INFO_SEARCH_TASK_DISPLAY_NAME_AUTHZ_DN("Authorization DN"),



  /**
   * Search Base DN
   */
  INFO_SEARCH_TASK_DISPLAY_NAME_BASE_DN("Search Base DN"),



  /**
   * Search Filter
   */
  INFO_SEARCH_TASK_DISPLAY_NAME_FILTER("Search Filter"),



  /**
   * Output File
   */
  INFO_SEARCH_TASK_DISPLAY_NAME_OUTPUT_FILE("Output File"),



  /**
   * Attribute to Return
   */
  INFO_SEARCH_TASK_DISPLAY_NAME_RETURN_ATTR("Attribute to Return"),



  /**
   * Search Scope
   */
  INFO_SEARCH_TASK_DISPLAY_NAME_SCOPE("Search Scope"),



  /**
   * May be used to add the contents of one or more files to the server schema.
   */
  INFO_TASK_DESCRIPTION_ADD_SCHEMA_FILE("May be used to add the contents of one or more files to the server schema."),



  /**
   * Cause the Directory Server to generate administrative alerts and/or manage the set of degraded and unavailable alert types reported in the general monitor entry.
   */
  INFO_TASK_DESCRIPTION_ALERT("Cause the Directory Server to generate administrative alerts and/or manage the set of degraded and unavailable alert types reported in the general monitor entry."),



  /**
   * This task may be used to initiate a data security audit in the Directory Server to look for potential issues in the data which may pose a security risk to the directory environment.
   */
  INFO_TASK_DESCRIPTION_AUDIT_DATA_SECURITY("This task may be used to initiate a data security audit in the Directory Server to look for potential issues in the data which may pose a security risk to the directory environment."),



  /**
   * May be used to back up the contents of one or more Directory Server backends.
   */
  INFO_TASK_DESCRIPTION_BACKUP("May be used to back up the contents of one or more Directory Server backends."),



  /**
   * May be used to terminate a client connection.
   */
  INFO_TASK_DESCRIPTION_DISCONNECT_CLIENT("May be used to terminate a client connection."),



  /**
   * Dump statistics about the contents of a Directory Server backend which stores its content in a Berkeley DB Java Edition database environment.  It reports information about the total and average size of keys and values in each database, along with the relative sizes of the databases.
   */
  INFO_TASK_DESCRIPTION_DUMP_DB("Dump statistics about the contents of a Directory Server backend which stores its content in a Berkeley DB Java Edition database environment.  It reports information about the total and average size of keys and values in each database, along with the relative sizes of the databases."),



  /**
   * May be used to cause the server to enter lockdown mode.  While in lockdown mode, the server will reject any connection attempts from remote clients, and will reject any request from non-root users.
   */
  INFO_TASK_DESCRIPTION_ENTER_LOCKDOWN_MODE("May be used to cause the server to enter lockdown mode.  While in lockdown mode, the server will reject any connection attempts from remote clients, and will reject any request from non-root users."),



  /**
   * May be used to export the contents of a Directory Server backend to LDIF.
   */
  INFO_TASK_DESCRIPTION_EXPORT("May be used to export the contents of a Directory Server backend to LDIF."),



  /**
   * A generic task which does not require any custom properties.
   */
  INFO_TASK_DESCRIPTION_GENERIC("A generic task which does not require any custom properties."),



  /**
   * Invoke a task encapsulated in a Groovy script using the UnboundID server SDK.
   */
  INFO_TASK_DESCRIPTION_GROOVY_SCRIPTED_TASK("Invoke a task encapsulated in a Groovy script using the UnboundID server SDK."),



  /**
   * May be used to import LDIF data into a Directory Server backend.
   */
  INFO_TASK_DESCRIPTION_IMPORT("May be used to import LDIF data into a Directory Server backend."),



  /**
   * May be used to cause the server to leave lockdown mode and resume normal operation.
   */
  INFO_TASK_DESCRIPTION_LEAVE_LOCKDOWN_MODE("May be used to cause the server to leave lockdown mode and resume normal operation."),



  /**
   * May be used to generate or rebuild Directory Server indexes.
   */
  INFO_TASK_DESCRIPTION_REBUILD("May be used to generate or rebuild Directory Server indexes."),



  /**
   * This task may be used to cause the server to re-encode all or a specified set of entries in a local DB backend.  This may be used to apply encoding changes around the use of features like compression, encryption, cryptographic digests, and/or uncached attributes or entries.
   */
  INFO_TASK_DESCRIPTION_REENCODE_ENTRIES("This task may be used to cause the server to re-encode all or a specified set of entries in a local DB backend.  This may be used to apply encoding changes around the use of features like compression, encryption, cryptographic digests, and/or uncached attributes or entries."),



  /**
   * Cause the Directory Server to immediately reload the encryption settings database from disk in order to make any changes available to the server
   */
  INFO_TASK_DESCRIPTION_REFRESH_ENCRYPTION_SETTINGS("Cause the Directory Server to immediately reload the encryption settings database from disk in order to make any changes available to the server"),



  /**
   * Reload the data for one or more entry-balancing global indexes from backend Directory Servers or a peer Directory Proxy Server.
   */
  INFO_TASK_DESCRIPTION_RELOAD_GLOBAL_INDEX("Reload the data for one or more entry-balancing global indexes from backend Directory Servers or a peer Directory Proxy Server."),



  /**
   * May be used to restore the contents of a Directory Server backend from a backup.
   */
  INFO_TASK_DESCRIPTION_RESTORE("May be used to restore the contents of a Directory Server backend from a backup."),



  /**
   * May be used to process an internal search within the Directory Server.
   */
  INFO_TASK_DESCRIPTION_SEARCH("May be used to process an internal search within the Directory Server."),



  /**
   * May be used to shut down or restart the Directory Server.
   */
  INFO_TASK_DESCRIPTION_SHUTDOWN("May be used to shut down or restart the Directory Server."),



  /**
   * Invoke a third-party task developed using the UnboundID server SDK.
   */
  INFO_TASK_DESCRIPTION_THIRD_PARTY_TASK("Invoke a third-party task developed using the UnboundID server SDK."),



  /**
   * Add Schema File
   */
  INFO_TASK_NAME_ADD_SCHEMA_FILE("Add Schema File"),



  /**
   * Administrative Alert
   */
  INFO_TASK_NAME_ALERT("Administrative Alert"),



  /**
   * Audit Data Security
   */
  INFO_TASK_NAME_AUDIT_DATA_SECURITY("Audit Data Security"),



  /**
   * Backup
   */
  INFO_TASK_NAME_BACKUP("Backup"),



  /**
   * Disconnect Client
   */
  INFO_TASK_NAME_DISCONNECT_CLIENT("Disconnect Client"),



  /**
   * Dump DB Details
   */
  INFO_TASK_NAME_DUMP_DB("Dump DB Details"),



  /**
   * Enter Lockdown Mode
   */
  INFO_TASK_NAME_ENTER_LOCKDOWN_MODE("Enter Lockdown Mode"),



  /**
   * LDIF Export
   */
  INFO_TASK_NAME_EXPORT("LDIF Export"),



  /**
   * Generic
   */
  INFO_TASK_NAME_GENERIC("Generic"),



  /**
   * Groovy-Scripted Task
   */
  INFO_TASK_NAME_GROOVY_SCRIPTED_TASK("Groovy-Scripted Task"),



  /**
   * LDIF Import
   */
  INFO_TASK_NAME_IMPORT("LDIF Import"),



  /**
   * Leave Lockdown Mode
   */
  INFO_TASK_NAME_LEAVE_LOCKDOWN_MODE("Leave Lockdown Mode"),



  /**
   * Rebuild Index
   */
  INFO_TASK_NAME_REBUILD("Rebuild Index"),



  /**
   * Re-Encode Entries Task
   */
  INFO_TASK_NAME_REENCODE_ENTRIES("Re-Encode Entries Task"),



  /**
   * Refresh Encryption Settings Task
   */
  INFO_TASK_NAME_REFRESH_ENCRYPTION_SETTINGS("Refresh Encryption Settings Task"),



  /**
   * Reload Global Index
   */
  INFO_TASK_NAME_RELOAD_GLOBAL_INDEX("Reload Global Index"),



  /**
   * Restore
   */
  INFO_TASK_NAME_RESTORE("Restore"),



  /**
   * Search
   */
  INFO_TASK_NAME_SEARCH("Search"),



  /**
   * Shutdown
   */
  INFO_TASK_NAME_SHUTDOWN("Shutdown"),



  /**
   * Third-Party Task
   */
  INFO_TASK_NAME_THIRD_PARTY_TASK("Third-Party Task");



  /**
   * The resource bundle that will be used to load the properties file.
   */
  private static final ResourceBundle RESOURCE_BUNDLE;
  static
  {
    ResourceBundle rb = null;
    try
    {
      rb = ResourceBundle.getBundle("unboundid-ldapsdk-task");
    } catch (Exception e) {}
    RESOURCE_BUNDLE = rb;
  }



  /**
   * The map that will be used to hold the unformatted message strings, indexed by property name.
   */
  private static final ConcurrentHashMap<TaskMessages,String> MESSAGE_STRINGS = new ConcurrentHashMap<TaskMessages,String>();



  /**
   * The map that will be used to hold the message format objects, indexed by property name.
   */
  private static final ConcurrentHashMap<TaskMessages,MessageFormat> MESSAGES = new ConcurrentHashMap<TaskMessages,MessageFormat>();



  // The default text for this message
  private final String defaultText;



  /**
   * Creates a new message key.
   */
  private TaskMessages(final String defaultText)
  {
    this.defaultText = defaultText;
  }



  /**
   * Retrieves a localized version of the message.
   * This method should only be used for messages which do not take any arguments.
   *
   * @return  A localized version of the message.
   */
  public String get()
  {
    String s = MESSAGE_STRINGS.get(this);
    if (s == null)
    {
      if (RESOURCE_BUNDLE == null)
      {
        return defaultText;
      }
      else
      {
        try
        {
          s = RESOURCE_BUNDLE.getString(name());
        }
        catch (final Exception e)
        {
          s = defaultText;
        }
        MESSAGE_STRINGS.putIfAbsent(this, s);
      }
    }
    return s;
  }



  /**
   * Retrieves a localized version of the message.
   *
   * @param  args  The arguments to use to format the message.
   *
   * @return  A localized version of the message.
   */
  public String get(final Object... args)
  {
    MessageFormat f = MESSAGES.get(this);
    if (f == null)
    {
      if (RESOURCE_BUNDLE == null)
      {
        f = new MessageFormat(defaultText);
      }
      else
      {
        try
        {
          f = new MessageFormat(RESOURCE_BUNDLE.getString(name()));
        }
        catch (final Exception e)
        {
          f = new MessageFormat(defaultText);
        }
      }
      MESSAGES.putIfAbsent(this, f);
    }
    synchronized (f)
    {
      return f.format(args);
    }
  }



  /**
   * Retrieves a string representation of this message key.
   *
   * @return  A string representation of this message key.
   */
  @Override()
  public String toString()
  {
    return get();
  }
}

